<?php
namespace WPUFA\classes\admin;

class UploadDetailsPage
{
	public function __construct()
	{
		add_action( 'add_meta_boxes_wpufa_upload', array( $this, 'add_meta_boxes' ) );
		add_action( 'admin_menu', array($this, 'remove_meta_boxes'));	
		add_filter( "get_user_option_screen_layout_wpufa_upload", array($this, 'set_page_layout') );
	}
	function add_meta_boxes() 
	{
		global $post;
		
		wp_enqueue_style('wpufa-upload-details-page', WPUFA_PLUGIN_PATH.'/css/admin/upload-details-page.css'); 
		
		add_meta_box( 'wpufa-fields', esc_html__('Input data', 'woocommerce-support-ticket-system'), array( &$this, 'render_submitted_data_meta_box' ), 'wpufa_upload', 'normal');
		add_meta_box( 'wpufa-uploads', esc_html__('Files', 'woocommerce-support-ticket-system'), array( &$this, 'render_files_meta_box' ), 'wpufa_upload', 'normal');
	}
	function remove_meta_boxes()
	{
		remove_meta_box( 'submitdiv', 'wpufa_upload', 'side' );
	}
	function set_page_layout()
	{
		return '1';
	}
	function render_files_meta_box()
	{
		global $post, $wpufa_upload_model, $wpufa_time_model, $wpufa_file_model;
		$field_id = $post->ID;
		$files_data = $wpufa_upload_model->get_meta($field_id, "_uploaded_files_data");
		$upload_dir = wp_upload_dir();
		if($files_data): 
			if(class_exists('ZipArchive')):?>
				<div class="wpufa-download-all-container">
					<a target="_blank" class="button button-primary" id="wpufa-download-all" href="<?php echo get_site_url();?>?wpufa_field_id=<?php echo $post->ID;?>"><?php esc_html_e('Download as zip', 'woocommerce-files-upload'); ?></a>
				</div>
		<?php  else: ?>
				<p><?php esc_html_e('To download all files as Zip, please make sure you have properly installed the ZipArchive PHP module.', 'woocommerce-support-ticket-system'); ?></p>
		<?php endif;
		foreach($files_data as $file_data): ?>
			  <div class="row">
				<div class="wpufa-image-file-preview"><?php if(!$wpufa_file_model->is_image($file_data['abs_path'])): ?>
						<img class="wpufa-image-list-element-img" src="<?php echo WPUFA_PLUGIN_PATH; ?>/img/generic-file-icon.png"></img>
					<?php else: ?>
						<img class="wpufa-image-list-element-img" src="<?php echo $upload_dir['baseurl'].$file_data['rel_path'].$file_data['name']; ?>"></img>
					<?php endif; ?>
				</div>
				<div class="wpufa-image-stats">						
					<span class="wpufa-image-name"><?php echo $file_data['name']; ?></span>
					<a class="button wpufa-download-button" href="<?php echo $upload_dir['baseurl'].$file_data['rel_path'].$file_data['name']; ?>" download><?php esc_html_e('Download', 'wordpress-upload-files-anywhere'); ?></a>
				</div>
			  </div>
		<?php endforeach;
		endif;
	}
	function render_submitted_data_meta_box()
	{
		global $post, $wpufa_upload_model, $wpufa_time_model, $wpufa_input_field_model;
		
		$field_id = $post->ID;
		$input_field_ids = $wpufa_upload_model->get_meta($field_id, "_input_field_ids");
		
		foreach($input_field_ids as $input_field_id)
		{
			$type = $wpufa_upload_model->get_meta($field_id, "_input_field_type_".$input_field_id);
			$label = $wpufa_upload_model->get_meta($field_id, "_input_field_label_".$input_field_id);
			$raw_value = $wpufa_upload_model->get_meta($field_id, '_input_field_value_'.$input_field_id);
			$value = $wpufa_input_field_model->get_value_by_type($raw_value, $type);
			
			
			?>
			<label class="wpufa_input_field_label"><?php  echo $label; ?></label>
			<span class="wpufa_input_field_value"><?php echo $value; ?></span>
			<?php
		}
	}
}
?>