<?php 
namespace WPUFA\classes\com;

class HTML
{
	var $input_fields_is_ajax_request = false;
	function __construct()
	{
		add_action('wp_ajax_wpufa_get_upload_field_configuration_template', array($this, 'ajax_get_upload_field_configuration_template'));
		add_action('wp_ajax_wpufa_add_new_input_field', array($this,'ajax_add_new_input_field'));
		add_action('wp_ajax_wpufa_duplicate_field', array($this,'ajax_duplicate_input_field'));
	}
	function ajax_get_upload_field_configuration_template()
	{
		if(wp_verify_nonce( wpufa_get_value_if_set($_POST, 'security', ""), 'wpufa_admin_field_configurator_page' ))
		{
			$fields_data = array(filter_input( INPUT_POST, 'start_index', FILTER_VALIDATE_INT ) => array());
			$this->get_upload_field_configuration_template($fields_data);
		}
		wp_die();
	}
	public function ajax_add_new_input_field()
	{
		$this->input_fields_is_ajax_request = true;
		if(wp_verify_nonce( wpufa_get_value_if_set($_POST, 'security', ""), 'wpufa_admin_field_configurator_page' ))
			$this->add_new_input_field(wpufa_get_value_if_set($_POST, 'type', "text"), filter_input( INPUT_POST, 'upload_field_id', FILTER_VALIDATE_INT ));
		wp_die();
	}
	public function ajax_duplicate_input_field()
	{
		global $wpufa_option_model;
		$this->input_fields_is_ajax_request = true;
		$upload_fields_options = $wpufa_option_model->get_upload_fields_options(); 
		
		if(wp_verify_nonce( wpufa_get_value_if_set($_POST, 'security', ""), 'wpufa_admin_field_configurator_page' ))
		{
			$index_to_duplicate = filter_input( INPUT_POST, 'index_to_duplicate', FILTER_VALIDATE_INT );
			$new_index = filter_input( INPUT_POST, 'start_index', FILTER_VALIDATE_INT );
			if(isset($upload_fields_options[$index_to_duplicate]))
			{
				$this->get_upload_field_configuration_template(array($new_index => $upload_fields_options[$index_to_duplicate]));
			}
		}
		wp_die();
	}
	public function add_new_input_field($type, $upload_field_id, $field_data = array(), $input_field_id = -1)
	{
		global $wpufa_wpml_model;
		$input_field_id = $input_field_id < 0 ? rand(0, 3129120123) : $input_field_id;
		$allowed_tags = array('br' => array(), 'p' => array(), 'strong' => array(), 'i' => array());
		
		include WPUFA_PLUGIN_ABS_PATH."/templates/admin/configurator/{$type}.php";
	}
	function render_input_fields($input_fields, $unique_upload_field_id)
	{
		global $wpufa_wpml_model, $wpufa_time_model, $wpufa_input_field_model;
		$current_lang = $wpufa_wpml_model->get_current_language();
		
		foreach($input_fields as $input_field_key => $input_field)
		{
			if(file_exists ( get_theme_file_path()."/wpufa/input/{$input_field['type']}.php" ))
					include get_theme_file_path()."/wpufa/input/{$input_field['type']}.php";
			else
				include WPUFA_PLUGIN_ABS_PATH."/templates/frontend/input/{$input_field['type']}.php";
		}
	}
	function get_upload_field_configuration_template($fields_data = array())
	{
		global $wpufa_wpml_model, $wpufa_user_model, $wpufa_upload_field_model;
		$allowed_tags = array('br' => array(), 'p' => array(), 'strong' => array(), 'i' => array(), 'span' => array());
		$langs =  $wpufa_wpml_model->get_langauges_list();
		
		foreach($fields_data as $field_id => $field_data): ?>
		<div class="wrap white-box" id="wpufa_field_container_<?php echo $field_id; ?>">
			<label class="wpufa_sort_button wpufa_no_margin_top ui-sortable-handle"><span class="dashicons dashicons-sort"></span><?php  esc_html_e('Drag to sort', 'wordpress-upload-files-anywhere'); ?></label>
			<div class="wpufa_title_container">
						<label class="wpufa_required wpufa_no_margin_top"><?php echo sprintf(esc_html__('[wpufa_upload_field id="%d"]', 'wordpress-upload-files-anywhere'), $field_id);?></label>
						<input type ="hidden" class="wpufa_field_options_id" name= "wpufa_field_options[<?php echo $field_id ?>][id]" value="<?php echo $field_id; ?>" ></input>
						<input type="text" placeholder="<?php  esc_html_e('Type the upload field title. HTML code is not allowed.', 'wordpress-upload-files-anywhere'); ?>" class="wpufa_upload_field_name" value="<?php esc_html_e(wpufa_get_value_if_set($field_data, 'title')); ?>" name="wpufa_field_options[<?php echo $field_id ?>][title]"  size="90" required></input >
						<button data-id="<?php echo $field_id ?>" class="button wpufa_collapse_options" id="wpuef_show_options_button_<?php echo $field_id; ?>"><?php esc_html_e('Show options', 'wordpress-upload-files-anywhere');?></button>
						<?php if(!empty($field_data)): ?>
						<a class="wpufa_tooltip duplicate_field button-secondary " data-id="<?php echo $field_id ?>">
							
								<?php esc_html_e('Duplicate field*', 'woocommerce-files-upload'); ?>
								<span><?php esc_html_e('The latest saved version will be the one that will be duplicated. So before duplicating a field, save it before.', 'woocommerce-files-upload');?></span>
						</a>
						<?php endif; ?>
						<button class="wpufa_remove_field button button-delete" data-id="<?php echo $field_id ?>"><?php esc_html_e('Delete field', 'wordpress-upload-files-anywhere');?></button>
			</div>
			<div class="wpufa_options_container" id="wpufa_options_container_<?php echo $field_id; ?>">
				<div class="wpufa_options_inner_container" id="wpufa_options_inner_container_<?php echo $field_id; ?>">
					<div class="wpufa_section_header_container header_container_small_margin">
						<h3 class="tab-title"><?php esc_html_e('Description, file types restriction, etc.', 'wordpress-upload-files-anywhere');?></h3>
					</div>
					<div class="half_block_fixed_container">
						<label class="option_label"><?php esc_html_e('Description (HTML code permitted)', 'wordpress-upload-files-anywhere');?></label>
						<?php foreach($langs as $lang_data): ?>
							<div class="wpufa_description_container">
								<?php if($lang_data['country_flag_url'] != "none"): ?>
									<img src=<?php esc_attr_e($lang_data['country_flag_url']); ?> /><label class="wpufa_label"> <?php esc_attr_e($lang_data['language_code']); ?></label>
								<?php endif; 
								$content = wpufa_get_value_if_set($field_data , array('description', $lang_data['language_code']), ""); 
								/* In case of rich editor text, the following code should be used: 
									wp_editor( $content, "wpufa_field_description_editor_{$field_id}_{$lang_data['language_code']}", array( 'media_buttons' => false,
																												   'textarea_rows' => 5,
																												   'tinymce' => true,
																												   "wpautop" => false,
																												   'editor_height' => 350,
																												   'textarea_name'=>"wpufa_field_options[{$field_id}][description][".$lang_data['language_code']."]"));*/
								?>
								<textarea class="upload_description"  rows="5" cols="80" name="wpufa_field_options[<?php echo $field_id ?>][description][<?php echo $lang_data['language_code']; ?>]" placeholder="<?php esc_html_e('Description (HTML code permitted)', 'wordpress-upload-files-anywhere'); ?>"><?php echo $content ?></textarea>
							</div>
					<?php endforeach; ?>
					
						
					</div>
							
					<div class="half_block_fixed_container">
						<label class="option_label"><?php esc_html_e('Allowed file type(s)', 'wordpress-upload-files-anywhere');?></label>
						<input type="text" name="wpufa_field_options[<?php echo $field_id ?>][types]" placeholder="<?php esc_html_e('File type(s), ex: .jpg,.bmp,.png leave empty to accept all file types. ', 'wordpress-upload-files-anywhere'); ?>" value="<?php echo wpufa_get_value_if_set($field_data, 'types') ?>" size="80"></input>
						
						<label class="option_label"><?php esc_html_e('Anonymous upload', 'wordpress-upload-files-anywhere');?></label>
						<p><?php esc_html_e('Allow not logged user to perform the upload', 'wordpress-upload-files-anywhere');?></p>
						<label class="switch">
								<input type="checkbox" name="wpufa_field_options[<?php echo $field_id ?>][anonymous_upload]" value="true" <?php checked(wpufa_get_value_if_set($field_data, 'anonymous_upload', "false"), "true") ?> ></input>
								<span class="slider"></span>
						</label>
						
						<label class="option_label"><?php esc_html_e('Single submission', 'wordpress-upload-files-anywhere');?></label>
						<p><?php esc_html_e('The user can perform an upload only one time. If this option is enabled, the user must be logged.', 'wordpress-upload-files-anywhere');?></p>
						<label class="switch">
								<input type="checkbox" name="wpufa_field_options[<?php echo $field_id ?>][single_submission]" class="master_option" data-related-id="user_can_delete_<?php echo $field_id ?>" data-id="<?php echo $field_id ?>" value="true" <?php checked(wpufa_get_value_if_set($field_data, 'single_submission', false), "true") ?> ></input>
								<span class="slider"></span>
						</label>
							
						<!-- <div class="master_related_user_can_delete_<?php echo $field_id ?> wpufa_master_related <?php if(!wpufa_get_value_if_set($field_data, 'user_can_delete', false)) echo 'wpufa_hidden'; ?>" >
							<label class="option_label"><?php esc_html_e('Can user delete file(s)?', 'wordpress-upload-files-anywhere');?></label>
							<p><?php esc_html_e('Once uploaded, the user will be able to delete and re-upload new files.', 'wordpress-upload-files-anywhere');?></p>
							<label class="switch">
								<input type="checkbox" name="wpufa_field_options[<?php echo $field_id ?>][user_can_delete]" value="true" <?php checked(wpufa_get_value_if_set($field_data, 'user_can_delete', "false"), "true") ?> ></input>
								<span class="slider"></span>
							</label>
						</div> -->
						
						<label class="option_label"><?php esc_html_e('Field container width', 'wordpress-upload-files-anywhere');?></label>
						<p><?php wpufa_html_escape_allowing_special_tags(__('The <span class="wpufa_green">main field container</span> can have a fixed width (px) or a percentage width (%). Express the value according to your needs. For example, if you need a fixed width of 200 pixel, enter <strong>200px</strong>. If you need a percentage of 20, enter <strong>20%</strong>', 'wordpress-upload-files-anywhere'), $allowed_tags);?></p>
						<input type="text" name="wpufa_field_options[<?php echo $field_id ?>][main_container][width]" value="<?php echo wpufa_get_value_if_set($field_data, array('main_container', 'width'), "");?>" placeholder="<?php esc_html_e('Example: 200px, 20%, etc', 'wordpress-upload-files-anywhere'); ?>"></input>
				
					</div>
					
					<div class="half_block_fixed_container">
						<label class="wpufa_already_uploaded_message_label"><?php esc_html_e('Text to show after the upload has been completed (HTML code permitted)', 'wordpress-upload-files-anywhere'); ?></label>
						<p><?php echo wp_kses(__('This text will be displayed after an upload has completed', 'wordpress-upload-files-anywhere'), $allowed_tags);?></p>
						<?php foreach($langs as $lang_data): ?>
								<div class="wpufa_description_container">
								<?php if($lang_data['country_flag_url'] != "none"): ?>
									<img src=<?php esc_attr_e($lang_data['country_flag_url']); ?> /><label class="wpufa_label"> <?php esc_attr_e($lang_data['language_code']); ?></label>
								<?php endif; ?>
								<textarea  class="upload_description"  rows="5" cols="80" name="wpufa_field_options[<?php echo $field_id ?>][message_already_uploaded][<?php echo $lang_data['language_code']; ?>]" placeholder="<?php esc_attr_e('This message is displayed after file description only if a file have been uploaded (you can use HTML code)', 'wordpress-upload-files-anywhere'); ?>"><?php echo wpufa_get_value_if_set($field_data , array('message_already_uploaded', $lang_data['language_code']), esc_html__('Upload completed, thank you!','wordpress-upload-files-anywhere') )?></textarea>
						</div>
						<?php endforeach; ?>
					</div>
					
					
					
				
					<div class="wpufa_section_header_container">
						<h3 class="tab-title"><?php esc_html_e('Single/Multiple files upload & size restriction', 'wordpress-upload-files-anywhere');?></h3>
					</div>
					
					<label class="option_label"  ><?php esc_html_e('Enable multiple files upload per single field?', 'wordpress-upload-files-anywhere');?></label>
					<label class="switch">	
						<input type="checkbox"  name="wpufa_field_options[<?php echo $field_id ?>][enable_multiple_uploads_per_field]" value="true" class="wpufa_multiple_files_upload_checkbox master_option" data-related-id="multiple_files_<?php echo $field_id ?>" data-id="<?php echo $field_id ?>" <?php checked(wpufa_get_value_if_set($field_data, 'enable_multiple_uploads_per_field', "false"), "true"); ?> ></input>
						<span class="slider"></span>
					</label>
					
					<div  id="wpufa_single_file_upload_options_container_<?php echo $field_id ?>" data-id="<?php echo $field_id ?>" class="wpufa_single_file_upload_options_container ">
						
						<div class="half_block_container">
							<label class="option_label wpufa_required"><?php esc_html_e('Min file size (MB) limit', 'wordpress-upload-files-anywhere');?></label>
							<p><?php esc_html_e('Leave 0 for no limits. In case of multiple files upload field, each uploaded file size cannot be greater of the specified value.', 'wordpress-upload-files-anywhere');?></p>
							<input type="number" min="0"  step="0.01" name="wpufa_field_options[<?php echo $field_id ?>][min_size]" value="<?php echo wpufa_get_value_if_set($field_data, 'min_size', 0);?>" required></input>
						</div>
						<div class="half_block_container">
							<label class="option_label wpufa_required"><?php esc_html_e('Max file size (MB) limit', 'wordpress-upload-files-anywhere');?></label>
							<p><?php esc_html_e('Leave 0 for no limits. In case of multiple files upload field, each uploaded file size cannot be greater of the specified value.', 'wordpress-upload-files-anywhere');?></p>
							<input type="number" min="0"  step="0.01" name="wpufa_field_options[<?php echo $field_id ?>][max_size]" value="<?php echo wpufa_get_value_if_set($field_data, 'max_size', 0);?>" required></input>
						</div>
					</div>
					
					<div id="wpufa_multiple_files_upload_options_container_<?php echo $field_id ?>" data-id="<?php echo $field_id ?>" class="wpufa_multiple_files_upload_options_container master_related_multiple_files_<?php echo $field_id ?> wpufa_master_related <?php if(!wpufa_get_value_if_set($field_data, 'enable_multiple_uploads_per_field', false)) echo 'wpufa_hidden'; ?>">	
						
						<div class="wpufa_standard_bordered_box">
							<h4><?php esc_html_e('Size sum restriction', 'wordpress-upload-files-anywhere');?></h4>
							<div class="half_block_container">
								<label class="wpufa_required"><?php esc_html_e('Min file sizes sum limit (MB)', 'wordpress-upload-files-anywhere');?></label>
								<p><?php echo  wp_kses(__('Leave 0 for no limit. The <strong>sum of the uploaded file sizes</strong> cannot be lesser of the following value.', 'wordpress-upload-files-anywhere'), $allowed_tags); ?></p>
								<input type="number" min="0" step="0.01" name="wpufa_field_options[<?php echo $field_id ?>][multiple_files_min_size_sum]" value="<?php echo wpufa_get_value_if_set($field_data, 'multiple_files_min_size_sum', 0) ?>"  required></input>
							</div>	
							<div class="half_block_container">
								<label  class="wpufa_required"><?php esc_html_e('Max file sizes sum limit (MB)', 'wordpress-upload-files-anywhere');?></label>
								<p><?php echo  wp_kses(__('Leave 0 for no limit. The <strong>sum of the uploaded file sizes</strong> cannot be greater of than following value.', 'wordpress-upload-files-anywhere'), $allowed_tags); ?></p>
								<input type="number" min="0" step="0.01" name="wpufa_field_options[<?php echo $field_id ?>][multiple_files_max_size_sum]" value="<?php echo wpufa_get_value_if_set($field_data, 'multiple_files_max_size_sum', 0); ?>"  required></input>
							</div>
						</div>
						
						
						<div class="wpufa_standard_bordered_box">
							<h4><?php esc_html_e('Quantity restriction', 'wordpress-upload-files-anywhere');?></h4>
							<p><?php wp_kses(__('Click on the <i>Upload files Configurator -> Options</i> menu to enable the special <strong>Enable quantity selection</strong> option that allows your customers to specify a quantity value for each uploaded file.', 'wordpress-upload-files-anywhere'), $allowed_tags);?></p>
							<div class="half_block_container">
								<label class="wpufa_required"><?php esc_html_e('Minimum number of files that can uploaded', 'wordpress-upload-files-anywhere');?></label>
								<p><?php  wp_kses(__('Leave 0 for no limits. This option will work <strong>ONLY</strong> if the <strong>Multiple files upload per single field</strong> option has been enabled','wordpress-upload-files-anywhere'), $allowed_tags); ?></p>
								<input type="number"  min="0" name="wpufa_field_options[<?php echo $field_id ?>][multiple_uploads_minimum_required_files]" value="<?php echo wpufa_get_value_if_set($field_data, 'multiple_uploads_minimum_required_files', 0); ?>" required></input>
							</div>
							<div class="half_block_container">
								<label  class="wpufa_required"><?php esc_html_e('Max number of files that can be uploaded', 'wordpress-upload-files-anywhere');?></label>
								<p><?php  wp_kses(__('Leave 0 for no limits. This option will work <strong>ONLY</strong> if the <strong>Multiple files upload per single field</strong> option has been enabled','wordpress-upload-files-anywhere'), $allowed_tags); ?></p>
								<input type="number"  min="0"  name="wpufa_field_options[<?php echo $field_id ?>][multiple_uploads_max_files]" value="<?php echo wpufa_get_value_if_set($field_data, 'multiple_uploads_max_files', 0) ?>"   required></input>
							</div>
						</div>
					</div>	

					<div class="wpufa_section_header_container">
						<h3 class="tab-title"><?php esc_html_e('Notifications & emails', 'wordpress-upload-files-anywhere');?></h3>
					</div>
					
					<div class="full_block_container">	
						<label class="option_label"><?php esc_html_e('Notify admin via email when customer completed the upload?', 'wordpress-upload-files-anywhere');?></label>
						<label class="switch">
							<input type="checkbox" name="wpufa_field_options[<?php echo $field_id ?>][notify_admin]" value="true" class="master_option" data-related-id="admin_notification_<?php echo $field_id;?>" <?php checked(wpufa_get_value_if_set($field_data, 'notify_admin', "false"), "true"); ?> ></input>
							<span class="slider"></span>
						</label>
					</div>
					<div class="wpufa_master_related master_related_admin_notification_<?php echo $field_id;?> <?php if(!wpufa_get_value_if_set($field_data, 'notify_admin', false)) echo 'wpufa_hidden'; ?>" >
						<div class="half_block_fixed_container">	
							<label class="option_label"><?php esc_html_e('Attach uploaded file to admin notification email?', 'wordpress-upload-files-anywhere');?></label>
							<p><?php esc_html_e('This option works only if admin notification email option has been enabled and for files stored locally.', 'wordpress-upload-files-anywhere'); ?><br/><?php wp_kses(__('<strong>Note:</strong> some some server email provider will not receive emails with attachments bigger than 10MB (<a target="_blank" href="https://www.outlook-apps.com/maximum-email-size/">Gmail: 25MB, Outlook and Hotmail 10MB,...</a>)', 'wordpress-upload-files-anywhere'), $allowed_tags); ?></p>
							<label class="switch">	
								<input type="checkbox" name="wpufa_field_options[<?php echo $field_id ?>][notify_attach_to_admin_email]" value="true" <?php checked(wpufa_get_value_if_set($field_data, 'notify_attach_to_admin_email', "false"),"true"); ?> ></input>
								<span class="slider"></span>
							</label>
						</div>
						<div class="half_block_fixed_container">	
							<label class="option_label"><?php esc_html_e('Recipient(s)', 'wordpress-upload-files-anywhere');?></label>
							<p><?php  esc_html_e('Leave empty to send notifications to site admin email address.', 'wordpress-upload-files-anywhere'); ?></p>
							<input type="text" name="wpufa_field_options[<?php echo $field_id ?>][notifications_recipients]" placeholder="<?php esc_html_e("You can insert multiple email addresses comma separated, ex.: 'admin@site.com, managment@site.com'", "wordpress-upload-files-anywhere"); ?>" value="<?php echo wpufa_get_value_if_set($field_data, 'notifications_recipients', ""); ?>" size="100"></input>
						</div>
					</div>
					
					<div class="wpufa_section_header_container">
						<h3 class="tab-title"><?php _e('User role', 'wordpress-upload-files-anywhere');?></h3>
					</div>
					<p class="section_description"><?php _e('<strong>Leave unselected to leave the upload field visible for all.</strong> Selecting at least one role will make the upload field to be visible/unvisible to that role. To allow not logged user to perform the upload, use the <strong>Anonymous upload</strong> option you find on top of the page.', 'wordpress-upload-files-anywhere');?></p>
					<label class="option_label"><?php _e('Visibility type', 'wordpress-upload-files-anywhere');?></label>		
					<select  class="upload_type"  name="wpufa_field_options[<?php echo $field_id ?>][roles_policy]">
					  <option value="allow" <?php selected(wpufa_get_value_if_set($field_data, 'roles_policy', "allow"), "allow"); ?>><?php _e('Allow for selected roles', 'wordpress-upload-files-anywhere');?></option>
					  <option value="deny" <?php selected(wpufa_get_value_if_set($field_data, 'roles_policy', "allow"), "deny"); ?>><?php _e('Deny for selected roles', 'wordpress-upload-files-anywhere');?></option>
					</select>
					
					<label class="option_label"><?php _e('Select roles', 'wordpress-upload-files-anywhere');?></label>	
					<?php foreach($wpufa_user_model->get_all_user_roles() as $role_code => $role_name): ?>
							<label style="font-weight:normal;"><input type="checkbox" <?php checked(wpufa_get_value_if_set($field_data, array('roles', $role_code), false)); ?> name="wpufa_field_options[<?php echo $field_id ?>][roles][<?php echo $role_code; ?>]" value="1"><?php echo $role_name['name'] ?></label>
					<?php endforeach; ?>
						<!-- <label style="font-weight:normal;"><input type="checkbox" <?php echo checked(wpufa_get_value_if_set($field_data, array('roles', 'not_logged'), false)); ?> name="wpufa_field_options[<?php echo $field_id ?>][roles][not_logged]" value="1"><?php _e('Guest (<strong>Not logged user</strong>)', 'wordpress-upload-files-anywhere');?></label> -->
					
					<div class="wpufa_section_header_container">
						<h3 class="tab-title"><?php _e('Input fields', 'wordpress-upload-files-anywhere');?></h3>
					</div>
					<select id="wpufa_input_fields_type_<?php echo $field_id;?>">
					  <option value="text" ><?php _e('Text', 'wordpress-upload-files-anywhere');?></option>
					  <option value="textarea" ><?php _e('Textarea', 'wordpress-upload-files-anywhere');?></option>
					  <option value="date" ><?php _e('Date', 'wordpress-upload-files-anywhere');?></option>
					  <option value="time" ><?php _e('Time', 'wordpress-upload-files-anywhere');?></option>
					  <option value="select" ><?php _e('Select/Multiselect', 'wordpress-upload-files-anywhere');?></option>
					  <option value="checkbox" ><?php _e('Checkbox', 'wordpress-upload-files-anywhere');?></option>
					</select>
					<button class="button-primary wpufa_add_new_input_field_button disable_during_animation" data-id="<?php echo $field_id;?>" ><?php esc_attr_e('Add new', 'wordpress-upload-files-anywhere'); ?></button>
					<div class="spinner load_new_input_field_spinner"></div>	
					<div class="wpufa_input_fields_container" id="wpufa_input_fields_container_<?php echo $field_id;?>">
					<?php 
						if(isset($field_data['input_fields'] ))
							foreach((array)$field_data['input_fields'] as $input_field_id => $input_field_data)
							{
								
								$this->add_new_input_field($input_field_data['type'], $field_id, $input_field_data, $input_field_id);
							}
					?>
					</div>
					
				</div>
			</div>
		</div>
		<?php 
		endforeach; //foreach $fields_data
	}

}
?>