<?php
namespace WPUFA\classes\com;


class Shortcode
{
	var $js_data = array();
	var $already_rendered = array();
	
	public function __construct()
	{
		add_shortcode( 'wpufa_upload_field', array($this, 'render_upload_field' ));
	}
	public function render_upload_field($atts, $content = null)
	{
		/*  To set defaults, example: 
		$a = shortcode_atts( array(
		'id' => get_current_user_id(),
		), $atts ); */
			
		
		if(!isset($atts['id']) || isset($already_rendered[$atts['id']]))
			return "";
		
		global $wpufa_file_model, $wpufa_option_model, $wpufa_wpml_model, $wpufa_user_model, $wpufa_html_model, $wpufa_time_model;
		
		$already_rendered[$atts['id']] = true; //Disable to allow rendering of the same upload field multiple times?
		$upload_fields_data = $wpufa_option_model->get_upload_fields_options(); 
		if(!isset($upload_fields_data[$atts['id']]))
			return;
		
		$field_id = $atts['id'];
		$upload_fields_data = $upload_fields_data[$atts['id']];
		$current_lang = $wpufa_wpml_model->get_current_language();
		$unique_id = $atts['id']."-".rand(1312, 999999); //a random number is added because if future, it will eventually be possible render the same upload field different time in a page
		$user_role_restriction_type = wpufa_get_value_if_set($upload_fields_data, 'roles_policy', "allow");
		$selected_roles = wpufa_get_value_if_set($upload_fields_data, array('roles'), array());
		$before_input_fields = array();
		$after_input_fields = array();
		
		if(isset($upload_fields_data["input_fields"]))
			foreach((array)$upload_fields_data["input_fields"] as $input_field_id => $field)
			{
				if($field['position'] == 'before')
					$before_input_fields[$input_field_id] = $field;
				else
					$after_input_fields[$input_field_id] = $field;
			}
		
		if(!$wpufa_user_model->belongs_to_seleceted_roles($user_role_restriction_type, $selected_roles))
			return;
		
		wp_enqueue_style('wpufa-dropzone', WPUFA_PLUGIN_PATH.'/css/vendor/dropzone/min/dropzone.min.css'); 
		wp_enqueue_style('wpufa-com-uploader', WPUFA_PLUGIN_PATH.'/css/vendor/vanquish/uploader.css'); 
		wp_enqueue_style('wpufa-input-fields', WPUFA_PLUGIN_PATH.'/css/frontend/input-fields.css'); 
		wp_enqueue_style('wpufa-upload-area', WPUFA_PLUGIN_PATH.'/css/frontend/upload-area.css'); 
		wp_enqueue_style('van-datepicker-classic', WPUFA_PLUGIN_PATH.'/css/vendor/datetimepicker/classic.css'); 
		wp_enqueue_style('van-datepicker-date-classic', WPUFA_PLUGIN_PATH.'/css/vendor/datetimepicker/classic.date.css'); 
		wp_enqueue_style('van-datepicker-time-classic', WPUFA_PLUGIN_PATH.'/css/vendor/datetimepicker/classic.time.css'); 
		wp_enqueue_style('select2', WPUFA_PLUGIN_PATH.'/css/vendor/select2/select2.min.css'); 
			
		
		wp_register_script( 'wpufa-shortcode-manager', WPUFA_PLUGIN_PATH.'/js/frontend/shortcode-manager.js', array('jquery') );	
		wp_register_script( 'wpufa-com-uploader-manager', WPUFA_PLUGIN_PATH.'/js/vendor/vanquish/upload-manager.js', array('jquery') );	
		$this->js_data[$unique_id] = array( 
						'ajax_url' => admin_url( 'admin-ajax.php' ) ,
						'unique_id' => $unique_id,
						'security' => wp_create_nonce('wpufa_security_'.$unique_id),
						'field_id' => $atts['id'],
						'chunk_size' => $wpufa_file_model->return_bytes($wpufa_file_model->get_php_settings('post_max_size')),
						'date_format' => 'yyyy-mm-dd',
						'time_format' => 'HH:i',
						'file_size_error' => esc_html__('file exceeds the size limit of: ', 'wordpress-upload-files-anywhere'),
						'file_min_size_error' => esc_html__('file is smaller of the minimum size of: ', 'wordpress-upload-files-anywhere'),
						'file_sum_size_error' => esc_html__('the sum of all file size exceeds the limit of: ', 'wordpress-upload-files-anywhere'),
						'file_sum_min_size_error' => esc_html__('The sum of all file size is under the minimum size of: ', 'wordpress-upload-files-anywhere'),
						'extension_error' => esc_html__('file type you are trying to upload is not permitted', 'wordpress-upload-files-anywhere'),
						'browser_compliant_error' => esc_html__('You browser is not HTML5 compliant', 'wordpress-upload-files-anywhere'),
						'missing_required_filed' => esc_html__('Please fill all the required fields', 'wordpress-upload-files-anywhere')
					);
		wp_localize_script('wpufa-shortcode-manager', 'wpufa', $this->js_data);
		wp_localize_script('wpufa-com-uploader-manager', 'wpufa', $this->js_data);
		
		
		wp_enqueue_script( 'wpufa-dropzone', WPUFA_PLUGIN_PATH.'/js/vendor/dropzone/min/dropzone.min.js', array('jquery') );	
		wp_enqueue_script( 'wpufa-com-uploader', WPUFA_PLUGIN_PATH.'/js/vendor/vanquish/uploader.js', array('jquery') );	
		wp_enqueue_script( 'van-picker', WPUFA_PLUGIN_PATH.'/js/vendor/datetimepicker/picker.js', array('jquery'));	
		wp_enqueue_script( 'van-datepicker', WPUFA_PLUGIN_PATH.'/js/vendor/datetimepicker/picker.date.js', array('jquery'));	
		wp_enqueue_script( 'van-timepicker', WPUFA_PLUGIN_PATH.'/js/vendor/datetimepicker/picker.time.js', array('jquery'));	
		wp_enqueue_script( 'select2', WPUFA_PLUGIN_PATH.'/js/vendor/select2/select2.full.min.js', array('jquery'));	
		$lang_code = str_replace("_formal", "",$wpufa_wpml_model->get_current_locale());
		if(wpufa_file_exists(WPUFA_PLUGIN_ABS_PATH.'/js/vendor/datetimepicker/translations/'.$lang_code.'.js'))
			wp_enqueue_script('van-datepicker-localization', WPUFA_PLUGIN_PATH.'/js/vendor/datetimepicker/translations/'.$lang_code.'.js');
		wp_enqueue_script( 'wpufa-shortcode-manager');	
		wp_enqueue_script( 'wpufa-com-uploader-manager');	
		
		ob_start();
		if(file_exists ( get_theme_file_path()."/wpufa/upload_field.php" ))
				include get_theme_file_path()."/wpufa/upload_field.php";
			else
				include WPUFA_PLUGIN_ABS_PATH.'/templates/frontend/upload_field.php';
			
		return ob_get_clean();
		
	}
}
?>