<?php 
namespace WPUFA\classes\com;

class Upload
{
	var $is_ajax_request = false;
	public function __construct()
	{
		add_action( 'init', array($this, 'register_custom_post_type'), 0 );
		add_action('before_delete_post', array( $this,'delete_associated_data'), 10);
		
		add_action('wp_ajax_wpufa_finalize_upload_process', array( $this,'ajax_finalize_upload_process'), 10);
		add_action('wp_ajax_nopriv_wpufa_finalize_upload_process', array( $this,'ajax_finalize_upload_process'), 10);
	}
	function register_custom_post_type() 
	{

		$labels = array(
			'name'                => _x( 'Uploads', 'Uploads', 'wordpress-upload-files-anywhere' ),
			'singular_name'       => _x( 'Upload', 'Upload', 'wordpress-upload-files-anywhere' ),
			'parent_item_colon'   =>esc_html__( 'Parent Item:', 'wordpress-upload-files-anywhere' ),
			'all_items'           =>esc_html__( 'All Upload', 'wordpress-upload-files-anywhere' ),
			'add_new_item'        =>esc_html__( 'Add Upload', 'wordpress-upload-files-anywhere' ),
			'add_new'             =>esc_html__( 'Add Upload', 'wordpress-upload-files-anywhere' ),
			'new_item'            =>esc_html__( 'New Upload', 'wordpress-upload-files-anywhere' ),
			'edit_item'           =>esc_html__( 'Edit Upload', 'wordpress-upload-files-anywhere' ),
			'update_item'         =>esc_html__( 'Update Upload', 'wordpress-upload-files-anywhere' ),
			'view_item'           =>esc_html__( 'View Upload', 'wordpress-upload-files-anywhere' ),
			'search_items'        =>esc_html__( 'Search Upload', 'wordpress-upload-files-anywhere' ),
			'not_found'           =>esc_html__( 'Not found', 'wordpress-upload-files-anywhere' ),
			'not_found_in_trash'  =>esc_html__( 'Not found in Trash', 'wordpress-upload-files-anywhere' ),
		);
		$args = array(
			'label'               =>esc_html__( 'Upload', 'wordpress-upload-files-anywhere' ),
			'description'         =>esc_html__( 'WordPress Upload Files Anywherel', 'wordpress-upload-files-anywhere' ),
			'labels'              => $labels,
			'supports'            => array(''),
			'taxonomies'          => array(  ),
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,                                     
			'show_in_menu'        => 'wpufa-wordpress-upload-files-anywhere',
			'show_in_admin_bar'   => false,
			'show_in_nav_menus'   => false,
			'can_export'          => true,
			'has_archive'         => false,		
			'exclude_from_search' => true,
			'publicly_queryable'  => false,
			'capability_type' => 'post',
			'capabilities' => array(
										
									  ),
		);
		register_post_type( 'wpufa_upload', $args );
		flush_rewrite_rules();	
	}
	public function delete_associated_data($post_id)
	{
		global $wpufa_file_model;
		$obj = get_post($post_id);
		if (!isset($obj) || $obj->post_type != 'wpufa_upload')
			return;
		
		$uploded_files_data = $this->get_meta($post_id, '_uploaded_files_data');
		
		if(!$uploded_files_data)
			return;
		/* To delete single file uncommet the following:
			foreach($uploded_files_data as $data)
			{
				 $wpufa_file_model->delete_file($data['rel_path']);
			}
		*/
	    $wpufa_file_model->delete_directory($post_id);
	}
	public function ajax_finalize_upload_process()
	{
		global $wpufa_file_model, $wpufa_option_model, $wpufa_wpml_model, $wpufa_input_field_model, $wpufa_email_model;
		
		if(!wp_verify_nonce( wpufa_get_value_if_set($_POST, 'security', ""), 'wpufa_security_'.$_POST['upload_field_unique_id'] ))
			wp_die();
		
		$debug = false;
		/* $_POST structure: 
			array(12) {
			  ["action"]=>
			  string(29) "wpufa_finalize_upload_process"
			  ["security"]=>
			  string(10) "76e2ec6e3f"
			  ["upload_field_id"]=>
			  string(1) "0"
			  ["upload_field_unique_id"]=>
			  string(8) "0-772741"
			  ["input_fields"]=>
			  array(5) {
				[151173350]=>
				string(3) "asd"
				[2618036302]=>
				string(10) "2021-06-23"
				[2587564232]=>
				string(5) "09:50"
				[883132879]=>
				string(6) "asdasd"
				[2525482375]=>
				string(8) "red,blue"
			  }
			  ["files"]=>
			  string(66) "file1.jpg,file2.jpg"
			  ["session_id"]=>
			  string(7) "5425982"
			}
		*/
		$upload_fields_data = $wpufa_option_model->get_upload_fields_options(); 
		if(!isset($upload_fields_data[$_POST['upload_field_id']]))
			wp_die();
		
		$upload_fields_data = $upload_fields_data[$_POST['upload_field_id']];
		$current_lang = $wpufa_wpml_model->get_current_language();
		$default_lang = $wpufa_wpml_model->get_default_language();
		$input_field_ids = array();
		
		$upload_field_unique_id = $_POST['upload_field_unique_id'];
		$upload_field_id = $_POST['upload_field_id'];
		$ids = explode("-", $upload_field_unique_id); // $ids[0]: field id, $ids[1]: random assigned to the field
		$id = wp_insert_post(array(
					'post_type' => 'wpufa_upload',
					'post_title' => $upload_fields_data['title'],
					'post_status' => 'publish'
				));
				
		$file_array = explode(",", $_POST['files']);
		$uploaded_files = $wpufa_file_model->move_file_after_upload($_POST['session_id'], $id, $file_array);
		
		//Input fields management
		if(isset($_POST["input_fields"]))
			foreach((array)$_POST["input_fields"] as $input_field_id => $field_value)
			{
				if(!isset($upload_fields_data["input_fields"][$input_field_id]))
					continue;
				
				$input_field_ids[] = $input_field_id;
				$type = $upload_fields_data["input_fields"][$input_field_id]['type'];
				if($type == 'select')
				{
					$selected_values = explode(",", $field_value);
					$field_value = array();
					$labels_and_values = $wpufa_input_field_model->get_select_labels_and_values($upload_fields_data["input_fields"][$input_field_id]['labels_and_values'], $default_lang);
					if(!empty($selected_values))
						foreach($selected_values as $selected_value)
							$field_value[] = $labels_and_values[$selected_value];
					
					$field_value = implode(",", $field_value);
				}
				
				if(!$debug)
				{
					$this->update_meta($id, '_input_field_label_'.$input_field_id , $upload_fields_data["input_fields"][$input_field_id]['label'][$default_lang]);
					$this->update_meta($id, '_input_field_value_'.$input_field_id , $field_value);
					$this->update_meta($id, '_input_field_type_'.$input_field_id , $upload_fields_data["input_fields"][$input_field_id]['type']);
				}
				else
				{
					wpufa_var_dump("*Input field*");
					wpufa_var_dump($upload_fields_data["input_fields"][$input_field_id]['label'][$default_lang]);
					wpufa_var_dump($field_value);
				}
				
			}
		//Files management
 		if(!$debug)
			$this->update_meta($id, '_uploaded_files_data' ,$uploaded_files);
		else
		{
			wpufa_var_dump("*Files*");
			wpufa_var_dump($uploaded_files);
		}
		
		
		if(!$debug)
		{
			$this->update_meta($id, '_input_field_ids' , $input_field_ids);
			$this->update_meta($id, '_user_id' , get_current_user_id());
		}
		
		//Email notification
		if(wpufa_get_value_if_set($upload_fields_data, 'notify_admin', "false") == "true")
		{
			$wpufa_email_model->send($id, $upload_fields_data);
		}
		do_action('wpufa_upload_performed', $id, $upload_field_id, $uploaded_files, $upload_fields_data); 
		wp_die();
	}
	public function get_user_id($upload_id)
	{
		$result = $this->get_meta($upload_id, '_user_id');
		return $result ? $result : 0;
	}
	public function update_meta($id, $name, $value)
	{
		return update_post_meta($id, $name, $value);
	}
	public function get_meta($id, $name, $single = true)
	{
		return get_post_meta($id, $name, $single);
	}
}
?>