"use strict";
Dropzone.autoDiscover = false; 
var wpufa_files_list = {};
var wpufa_drop_zones_list = {};
jQuery(document).ready(function()
{

	wpufa_init_upload_area();

	jQuery(document).on('click', '.drop-zone__thumb-close_button', wpufa_remove_preview_thumb);
	
	//init file lists
	const fields_ids = Object.keys(wpufa);
	for(var i = 0; i < fields_ids.length; i++)
		wpufa_files_list[fields_ids[i]] = {};
	
	wpufa_init_date_and_fields();
	wpufa_init_select2_fields();
});
function wpufa_init_upload_area()
{
	
	document.querySelectorAll(".drop-zone__input").forEach((inputElement) => 
	{
        const dropZoneElement = inputElement.closest(".drop-zone");
		
		wpufa_drop_zones_list[jQuery(dropZoneElement).data('id')] = dropZoneElement;
		
        dropZoneElement.addEventListener("click", (event) => 
		{
			//If the "X" is clicked, the file selction dialog is not promped
			if(event.target.className == 'drop-zone__thumb-close_button')
				return;
			
			//if upload on progress
		   if(wpufa_num_uploads > 0)
			   return;
          inputElement.click(); /*clicking on input element whenever the dropzone is clicked so file browser is opened*/
        });

        inputElement.addEventListener("change", (event) => 
		{
           wpufa_update_manage_file_selection_on_change(event, dropZoneElement, inputElement);
        });
		
        dropZoneElement.addEventListener("dragover", (event) => 
		{
          event.preventDefault(); /*this along with prevDef in drop event prevent browser from opening file in a new tab*/
          dropZoneElement.classList.add("drop-zone--over");
        });
		
        ["dragleave", "dragend"].forEach((type) => {
          dropZoneElement.addEventListener(type, (event) => {
            dropZoneElement.classList.remove("drop-zone--over");
          });
        });
		
        dropZoneElement.addEventListener("drop", (event) => 
		{
          
		  wpufa_update_manage_file_selection_on_drop(event, dropZoneElement, inputElement);
          dropZoneElement.classList.remove("drop-zone--over");
        });
		
    });
}
function wpufa_update_manage_file_selection_on_change(event,dropZoneElement, inputElement)
{
	
	const id = jQuery(inputElement).data('id');
	 if (inputElement.files.length) 
	  {
		  for(var i = 0; i < inputElement.files.length; i++)
		  {
			 wpufa_update_thumb(dropZoneElement, inputElement.files[i], wpufa_generate_unique_id(), id);
		  }
	  }
	 
}
function wpufa_update_manage_file_selection_on_drop(event, dropZoneElement, inputElement)
{
	 event.preventDefault();
	 const id = jQuery(inputElement).data('id');
	 if (event.dataTransfer.files.length) 
	 {
		inputElement.files =
		  event.dataTransfer.files; /*asigns dragged file to inputElement*/

		for(var i = 0; i < event.dataTransfer.files.length; i++)
		 {
			wpufa_update_thumb(
			  dropZoneElement,
			  event.dataTransfer.files[i],  wpufa_generate_unique_id(), id
			); /*thumbnail will only show first file if multiple files are selected*/
		 }
	  }
}
function wpufa_generate_unique_id()
{
	return (new Date().getTime()) + Math.floor(Math.random() * 1000);
}
function wpufa_update_thumb(dropZoneElement, file, i, id) 
{
	
	wpufa_files_list[id][i] = file;
	var is_multiple = jQuery(dropZoneElement).data('is-multiple');
	
	let thumbnailElement = dropZoneElement.querySelector(
	  ".drop-zone__thumb"
	);
	/*remove text prompt*/
	if (dropZoneElement.querySelector(".drop-zone__prompt")) {
	  //To remove: dropZoneElement.querySelector(".drop-zone__prompt").remove();
	  dropZoneElement.querySelector(".drop-zone__prompt").style.display = 'none';
	  
	}
	
	//UI
	if (is_multiple || !thumbnailElement) 
	{
	  thumbnailElement = document.createElement("div");
	  let closeButton = document.createElement("div");
	  closeButton.innerHTML = "X";
	  thumbnailElement.classList.add("drop-zone__thumb");
	  closeButton.classList.add("drop-zone__thumb-close_button");
	  closeButton.setAttribute("data-file-unique-id", i);
	  closeButton.setAttribute("data-field-id", id);
	  dropZoneElement.appendChild(thumbnailElement);
	  thumbnailElement.appendChild(closeButton);
	  jQuery('#wpufa-upload-button-'+id).fadeIn(); 
	  
	}
	thumbnailElement.dataset.label =
	  file.name; /*takes file name and sets it as dataset label so css can display it*/

	/*show thumbnail for images*/
	if (file.type.startsWith("image/")) 
	{
	  const reader = new FileReader(); /*lets us read files to data URL*/
	  reader.readAsDataURL(file); /*base 64 format*/
	  reader.onload = () => {
		thumbnailElement.style.backgroundImage = `url('${reader.result}')`; /*asynchronous call. This function runs once reader is done reading file. reader.result is the base 64 format*/
		thumbnailElement.style.backgroundPosition = "center";
	  };
	} 
	else {
	  thumbnailElement.style.backgroundImage = null; /*plain background for non image type files*/
	}
}

function wpufa_remove_preview_thumb(event)
{
	event.preventDefault();
	event.stopImmediatePropagation();
	const index = jQuery(event.currentTarget).data('file-unique-id');
	const id = jQuery(event.currentTarget).data('field-id');
	delete wpufa_files_list[id][index];
	
	
	jQuery(event.currentTarget).parent().fadeOut(300, function() 
	{ 
		//On complete 
		jQuery(this).remove(); 
		//UI
		if(Object.keys(wpufa_files_list[id]).length === 0)
		{
			jQuery('#wpufa_input_file_'+id).val('');  //On chrome, this prevent that removeing and adding the same file, the preview is not displayed
			wpufa_drop_zones_list[id].querySelector(".drop-zone__prompt").style.display = 'block';
			
		}
	});
	//UI
	if(Object.keys(wpufa_files_list[id]).length === 0)
		jQuery('#wpufa-upload-button-'+id).fadeOut(); 
	
	
	return false;
}
function wpufa_init_date_and_fields()
{
	jQuery('.wpufa_input_time_field').each(function(index, elem)
	{
		var id = jQuery(elem).data('upload-field-id');
		var min = jQuery(elem).data('min');
		var max = jQuery(elem).data('max');
		var time_interval = jQuery(elem).data('interval');
		min = min != null && min != "" ? min.split(",") : "";
		max = max != null && max != "" ? max.split(",") : "";
		jQuery(elem).pickatime({
		  format: wpufa[id].time_format,//'HH:i',//wpufa_datetime.time_format
		  formatSubmit: 'HH:i',
		   hiddenSuffix: '',
		   min: min,
		   max: max,
		   interval:time_interval
			
		});
	});
	
	jQuery('.wpufa_input_date_field').each(function(index, elem)
	{
		var min = jQuery(elem).data('min-date');
		var max = jQuery(elem).data('max-date');
		var id = jQuery(elem).data('upload-field-id');
		var days_to_disable = jQuery(elem).data('week-days-to-disable')+"";
		var specific_dates_to_disable = jQuery(elem).data('dates-to-exclude')+"";
		min = min != null && min != "" ? min.split(",") : "";
		max = max != null && max != "" ? max.split(",") : "";
		
		if(max != "")
			max[1] = max[1] - 1 ;
		if(min != "")
			min[1] = min[1] - 1 ;
		
		if(days_to_disable == "none" || days_to_disable == null)
			days_to_disable = [];
		else 
		{
			var day_values = days_to_disable.split(",");
			days_to_disable = [];
			for(var i = 0; i < day_values.length; i++)
				days_to_disable.push(parseInt(day_values[i]));
		
		}
		
		if(specific_dates_to_disable != "" && specific_dates_to_disable != "undefined")
		{
			var dates = specific_dates_to_disable.split(";");
			for(var i = 0; i < dates.length; i++)
				days_to_disable.push(dates[i].split(","));
		}
		
		jQuery(elem).pickadate({
			 firstDay: 1,
			 format: wpufa[id].date_format,//'yyyy-mm-dd',  
			 formatSubmit: 'yyyy-mm-dd',
			 hiddenSuffix: '',
			 min: min,
			 max: max,
			 selectYears: 300,
			 selectMonths: true,
			 klass: {
				 selectMonth: 'wpufa_picker__select--month',
				 selectYear: 'wpufa_picker__select--year'
			 },
			 disable: days_to_disable
			
		});
	});
}
function wpufa_init_select2_fields()
{
	jQuery('.wpufa_input_select_field').each(function(index,elem)
	{
		jQuery(elem).select2(
			{
				width: '100%',
				placeholder: jQuery(elem).prop('placeholder')
			});
	});
}